@@ -186,6 +186,14 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
     def get_impuestos(self):
         try:
             impuestos = self.dom.createElement('cfdi:Impuestos')
+            if len(self.impuestos_trasladados) > 0:
+                traslados = self.dom.createElement('cfdi:Traslados')
+                total_traslados = 0
+                for traslado in self.impuestos_trasladados:
+                    total_traslados += float(traslado.get('importe', 0))
+                    traslados.appendChild(self.get_traslados(traslado))
+                impuestos.appendChild(traslados)
+                impuestos.setAttribute('TotalImpuestosTrasladados', str(total_traslados))
             if len(self.impuestos_retenidos) > 0:
                 retenciones = self.dom.createElement('cfdi:Retenciones')
                 total_retenciones = 0
@@ -195,14 +203,6 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 impuestos.appendChild(retenciones)
                 impuestos.setAttribute('TotalImpuestosRetenidos', str(total_retenciones))
 
-            if len(self.impuestos_trasladados) > 0:
-                traslados = self.dom.createElement('cfdi:Traslados')
-                total_traslados = 0
-                for traslado in self.impuestos_trasladados:
-                    total_traslados += float(traslado.get('importe', 0))
-                    impuestos.appendChild(self.get_traslados(traslado))
-                impuestos.appendChild(traslados)
-                impuestos.setAttribute('TotalImpuestosTrasladados', str(total_traslados))
             return impuestos
         except Exception as e:
             raise Exception("Ocurrio un error. Error::: " + str(e))
